@@ -3,7 +3,7 @@
 # daemon/daemon.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
-# Copyright © 2008–2015 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2008–2016 Ben Finney <ben+python@benfinney.id.au>
 # Copyright © 2007–2008 Robert Niederreiter, Jens Klein
 # Copyright © 2004–2005 Chad J. Schroeder
 # Copyright © 2003 Clark Evans
@@ -37,6 +37,8 @@ except NameError:
     basestring = str
     unicode = str
 
+__metaclass__ = type
+
 
 class DaemonError(Exception):
     """ Base exception class for errors from this module. """
@@ -198,10 +200,13 @@ class DaemonContext:
             process.
 
         `initgroups`
-            :Default: ``True``
+            :Default: ``False``
 
-            If true, set the daemon process's supplementary groups
-            according to `uid`.
+            If true, set the daemon process's supplementary groups as
+            determined by the specified `uid`.
+
+            This will require that the current process UID has
+            permission to change the process's owning GID.
 
         `prevent_core`
             :Default: ``True``
@@ -235,8 +240,6 @@ class DaemonContext:
 
         """
 
-    __metaclass__ = type
-
     def __init__(
             self,
             chroot_directory=None,
@@ -244,7 +247,7 @@ class DaemonContext:
             umask=0,
             uid=None,
             gid=None,
-            initgroups=True,
+            initgroups=False,
             prevent_core=True,
             detach_process=None,
             files_preserve=None,
@@ -602,7 +605,7 @@ def get_username_for_uid(uid):
     return username
 
 
-def change_process_owner(uid, gid, initgroups=True):
+def change_process_owner(uid, gid, initgroups=False):
     """ Change the owning UID, GID, and groups of this process.
 
         :param uid: The target UID for the daemon process.
@@ -837,14 +840,16 @@ def get_maximum_file_descriptors():
         of ``MAXFD`` is returned.
 
         """
-    limits = resource.getrlimit(resource.RLIMIT_NOFILE)
-    result = limits[1]
-    if result == resource.RLIM_INFINITY:
+    (__, hard_limit) = resource.getrlimit(resource.RLIMIT_NOFILE)
+
+    result = hard_limit
+    if hard_limit == resource.RLIM_INFINITY:
         result = MAXFD
+
     return result
 
 
-def close_all_open_files(exclude=set()):
+def close_all_open_files(exclude=None):
     """ Close all open file descriptors.
 
         :param exclude: Collection of file descriptors to skip when closing
@@ -856,6 +861,8 @@ def close_all_open_files(exclude=set()):
         close.
 
         """
+    if exclude is None:
+        exclude = set()
     maxfd = get_maximum_file_descriptors()
     for fd in reversed(range(maxfd)):
         if fd not in exclude:
